@@ -1,4 +1,4 @@
-// Copyright (C) 2024 Hibiki AI Limited <info@hibiki-ai.com>
+// Copyright (C) 2024-2025 Hibiki AI Limited <info@hibiki-ai.com>
 //
 // This file is part of secretbase.
 //
@@ -377,15 +377,16 @@ static void mbedtls_sha256_finish(mbedtls_sha256_context *ctx,
 
 static inline void hash_bytes(R_outpstream_t stream, void *src, int len) {
   
-  secretbase_sha256_context *sctx = (secretbase_sha256_context *) stream->data;
-  sctx->skip ? (void) sctx->skip-- : mbedtls_sha256_update(sctx->ctx, (uint8_t *) src, (size_t) len);
+  secretbase_context *sctx = (secretbase_context *) stream->data;
+  sctx->skip ? (void) sctx->skip-- :
+    mbedtls_sha256_update((mbedtls_sha256_context *) sctx->ctx, (uint8_t *) src, (size_t) len);
   
 }
 
 static void hash_file(mbedtls_sha256_context *ctx, const SEXP x) {
   
   SB_ASSERT_STR(x);
-  const char *file = R_ExpandFileName(SB_STRING(x));
+  const char *file = R_ExpandFileName(CHAR(*STRING_PTR_RO(x)));
   unsigned char buf[SB_BUF_SIZE];
   FILE *f;
   size_t cur;
@@ -412,7 +413,7 @@ static void hash_object(mbedtls_sha256_context *ctx, const SEXP x) {
   switch (TYPEOF(x)) {
   case STRSXP:
     if (XLENGTH(x) == 1 && !ANY_ATTRIB(x)) {
-      const char *s = SB_STRING(x);
+      const char *s = CHAR(*STRING_PTR_RO(x));
       mbedtls_sha256_update(ctx, (uint8_t *) s, strlen(s));
       return;
     }
@@ -425,7 +426,7 @@ static void hash_object(mbedtls_sha256_context *ctx, const SEXP x) {
     break;
   }
   
-  secretbase_sha256_context sctx;
+  secretbase_context sctx;
   sctx.skip = SB_SERIAL_HEADERS;
   sctx.ctx = ctx;
   
@@ -470,7 +471,7 @@ static SEXP secretbase_sha256_impl(const SEXP x, const SEXP key, const SEXP conv
     
     switch (TYPEOF(key)) {
     case STRSXP:
-      data = (unsigned char *) (XLENGTH(key) ? SB_STRING(key) : "");
+      data = (unsigned char *) (XLENGTH(key) ? CHAR(*STRING_PTR_RO(key)) : "");
       klen = strlen((char *) data);
       break;
     case RAWSXP:
